@@ -6,7 +6,7 @@ package Blockchain::Ethereum::Keystore;
 class Blockchain::Ethereum::Keystore;
 
 our $AUTHORITY = 'cpan:REFECO';    # AUTHORITY
-our $VERSION   = '0.008';          # VERSION
+our $VERSION   = '0.009';          # VERSION
 
 1;
 
@@ -22,7 +22,7 @@ Blockchain::Ethereum::Keystore - Ethereum wallet management utilities
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -49,7 +49,7 @@ Importing a keyfile and changing the password:
     my $keyfile = Blockchain::Ethereum::Keystore::Keyfile->new;
     my $password = "old_password";
     $keyfile->import_file("...", $password);
-    $keyfile->change_password($password, "newpassword");
+    $keyfile->change_password($password, "new_password");
     $keyfile->write_to_file("...");
 
 Signing a transaction:
